Documentation
¶
Index ¶
- Constants
- type AttachConfig
- type Container
- type ContainerConfig
- type ContainerConfigVolumes
- type ContainerConfigWrapper
- type ContainerCreateResp
- type ContainerInfo
- type ContainerStartConfig
- type ContainerState
- type ContainerStatus
- type EndpointSettings
- type EngineVersion
- type Error
- type HostConfig
- type HostConfigAO0LogConfig
- type HostConfigPortBindingsAnon
- type Image
- type ImageSummary
- type SearchResultItem
- type SystemInfo
- type SystemVersion
- type VolumeConfig
- type VolumeCreateRequest
- type VolumeInfo
- type VolumeListResp
Constants ¶
const ( // HostConfigAO0LogConfigTypeJSONFile captures enum value "json-file" HostConfigAO0LogConfigTypeJSONFile string = "json-file" // HostConfigAO0LogConfigTypeSyslog captures enum value "syslog" HostConfigAO0LogConfigTypeSyslog string = "syslog" // HostConfigAO0LogConfigTypeJournald captures enum value "journald" HostConfigAO0LogConfigTypeJournald string = "journald" // HostConfigAO0LogConfigTypeGelf captures enum value "gelf" HostConfigAO0LogConfigTypeGelf string = "gelf" // HostConfigAO0LogConfigTypeFluentd captures enum value "fluentd" HostConfigAO0LogConfigTypeFluentd string = "fluentd" // HostConfigAO0LogConfigTypeAwslogs captures enum value "awslogs" HostConfigAO0LogConfigTypeAwslogs string = "awslogs" // HostConfigAO0LogConfigTypeSplunk captures enum value "splunk" HostConfigAO0LogConfigTypeSplunk string = "splunk" // HostConfigAO0LogConfigTypeEtwlogs captures enum value "etwlogs" HostConfigAO0LogConfigTypeEtwlogs string = "etwlogs" // HostConfigAO0LogConfigTypeNone captures enum value "none" HostConfigAO0LogConfigTypeNone string = "none" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AttachConfig ¶
AttachConfig wraps some infos of attaching.
type Container ¶
type Container struct {
// command
Command string `json:"Command,omitempty"`
// created
Created int64 `json:"Created,omitempty"`
// host config
HostConfig *HostConfig `json:"HostConfig,omitempty"`
// ID
ID string `json:"ID,omitempty"`
// image
Image string `json:"Image,omitempty"`
// image ID
ImageID string `json:"ImageID,omitempty"`
// labels
Labels map[string]string `json:"Labels,omitempty"`
// names
Names []string `json:"Names"`
// size root fs
SizeRootFs int64 `json:"SizeRootFs,omitempty"`
// size rw
SizeRw int64 `json:"SizeRw,omitempty"`
// state
State string `json:"State,omitempty"`
// status
Status string `json:"Status,omitempty"`
}
func (*Container) MarshalBinary ¶
MarshalBinary interface implementation
func (*Container) UnmarshalBinary ¶
UnmarshalBinary interface implementation
type ContainerConfig ¶
type ContainerConfig struct {
// Command is already escaped (Windows only)
ArgsEscaped bool `json:"ArgsEscaped,omitempty"`
// Whether to attach to `stderr`.
AttachStderr *bool `json:"AttachStderr,omitempty"`
// Whether to attach to `stdin`.
AttachStdin *bool `json:"AttachStdin,omitempty"`
// Whether to attach to `stdout`.
AttachStdout *bool `json:"AttachStdout,omitempty"`
// Command to run specified as a string or an array of strings.
Cmd []string `json:"Cmd"`
// The domain name to use for the container.
Domainname string `json:"Domainname,omitempty"`
// The entry point for the container as a string or an array of strings.
// If the array consists of exactly one empty string (`[""]`) then the entry point is reset to system default (i.e., the entry point used by docker when there is no `ENTRYPOINT` instruction in the `Dockerfile`).
//
Entrypoint []string `json:"Entrypoint"`
// A list of environment variables to set inside the container in the form `["VAR=value", ...]`. A variable without `=` is removed from the environment, rather than to have an empty value.
//
Env []string `json:"Env"`
// An object mapping ports to an empty object in the form:
//
// `{"<port>/<tcp|udp>": {}}`
//
ExposedPorts map[string]interface{} `json:"ExposedPorts,omitempty"`
// The hostname to use for the container, as a valid RFC 1123 hostname.
Hostname string `json:"Hostname,omitempty"`
// The name of the image to use when creating the container
Image string `json:"Image,omitempty"`
// User-defined key/value metadata.
Labels map[string]string `json:"Labels,omitempty"`
// MAC address of the container.
MacAddress string `json:"MacAddress,omitempty"`
// Disable networking for the container.
NetworkDisabled bool `json:"NetworkDisabled,omitempty"`
// `ONBUILD` metadata that were defined in the image's `Dockerfile`.
OnBuild []string `json:"OnBuild"`
// Open `stdin`
OpenStdin *bool `json:"OpenStdin,omitempty"`
// Shell for when `RUN`, `CMD`, and `ENTRYPOINT` uses a shell.
Shell []string `json:"Shell"`
// Close `stdin` after one attached client disconnects
StdinOnce *bool `json:"StdinOnce,omitempty"`
// Signal to stop a container as a string or unsigned integer.
StopSignal *string `json:"StopSignal,omitempty"`
// Timeout to stop a container in seconds.
StopTimeout *int64 `json:"StopTimeout,omitempty"`
// Attach standard streams to a TTY, including `stdin` if it is not closed.
Tty *bool `json:"Tty,omitempty"`
// The user that commands are run as inside the container.
User string `json:"User,omitempty"`
// volumes
Volumes *ContainerConfigVolumes `json:"Volumes,omitempty"`
// The working directory for commands to run in.
WorkingDir string `json:"WorkingDir,omitempty"`
}
func (*ContainerConfig) MarshalBinary ¶
func (m *ContainerConfig) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*ContainerConfig) UnmarshalBinary ¶
func (m *ContainerConfig) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type ContainerConfigVolumes ¶
type ContainerConfigVolumes struct {
// additional properties
AdditionalProperties interface{} `json:"additionalProperties,omitempty"`
}
func (*ContainerConfigVolumes) MarshalBinary ¶
func (m *ContainerConfigVolumes) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*ContainerConfigVolumes) UnmarshalBinary ¶
func (m *ContainerConfigVolumes) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type ContainerConfigWrapper ¶
type ContainerConfigWrapper struct {
*ContainerConfig
HostConfig *HostConfig `json:"HostConfig,omitempty"`
}
ContainerConfigWrapper is a type include config and host config of a container.
type ContainerCreateResp ¶
type ContainerCreateResp struct {
// The ID of the created container
// Required: true
ID string `json:"Id"`
// Then name of the created container
Name string `json:"Name,omitempty"`
// Warnings encountered when creating the container
// Required: true
Warnings []string `json:"Warnings"`
}
func (*ContainerCreateResp) MarshalBinary ¶
func (m *ContainerCreateResp) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*ContainerCreateResp) UnmarshalBinary ¶
func (m *ContainerCreateResp) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type ContainerInfo ¶
type ContainerInfo struct {
*ContainerState
Config *ContainerConfigWrapper
ID string
Name string
DetachKeys string
}
ContainerInfo accommodates container state and container configuration
func (*ContainerInfo) Key ¶
func (c *ContainerInfo) Key() string
Key returns a key that stands for a container info which is the index in meta store.
type ContainerStartConfig ¶
ContainerStartConfig accommodates all parameters need by starting container
type ContainerState ¶
type ContainerState struct {
StartedAt time.Time
Status ContainerStatus
FinishedAt time.Time
Pid int
ExitCodeValue int `json:"ExitCode"`
ErrorMsg string `json:"Error"` // contains last known error when starting the container
}
ContainerState houses container status, start and stop information
type ContainerStatus ¶
type ContainerStatus int
ContainerStatus is a enum type and indicates container status
const ( CREATED ContainerStatus = iota RUNNING PAUSED RESTARTING OOMKILLED REMOVALINPROGRESS STOPPING STOPPED DEAD )
container status enums
func (ContainerStatus) String ¶
func (s ContainerStatus) String() string
String returns the container's status by string.
type EndpointSettings ¶
type EndpointSettings struct {
// aliases
Aliases []string `json:"Aliases"`
// DriverOpts is a mapping of driver options and values. These options
// are passed directly to the driver and are driver specific.
//
DriverOpts map[string]string `json:"DriverOpts,omitempty"`
// Unique ID for the service endpoint in a Sandbox.
//
EndpointID string `json:"EndpointID,omitempty"`
// Gateway address for this network.
//
Gateway string `json:"Gateway,omitempty"`
// Global IPv6 address.
//
GlobalIPV6Address string `json:"GlobalIPv6Address,omitempty"`
// Mask length of the global IPv6 address.
//
GlobalIPV6PrefixLen int64 `json:"GlobalIPv6PrefixLen,omitempty"`
// IPv4 address.
//
IPAddress string `json:"IPAddress,omitempty"`
// Mask length of the IPv4 address.
//
IPPrefixLen int64 `json:"IPPrefixLen,omitempty"`
// IPv6 gateway address.
//
IPV6Gateway string `json:"IPv6Gateway,omitempty"`
// links
Links []string `json:"Links"`
// MAC address for the endpoint on this network.
//
MacAddress string `json:"MacAddress,omitempty"`
// Unique ID of the network.
//
NetworkID string `json:"NetworkID,omitempty"`
}
func (*EndpointSettings) MarshalBinary ¶
func (m *EndpointSettings) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*EndpointSettings) UnmarshalBinary ¶
func (m *EndpointSettings) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type EngineVersion ¶
type EngineVersion struct {
// Api Version held by Pouchd
APIVersion string `json:"ApiVersion,omitempty"`
// arch
Arch string `json:"Arch,omitempty"`
// build time
BuildTime string `json:"BuildTime,omitempty"`
// experimental
Experimental bool `json:"Experimental,omitempty"`
// Commit ID held by the latest commit operation
GitCommit string `json:"GitCommit,omitempty"`
// go version
GoVersion string `json:"GoVersion,omitempty"`
// kernel version
KernelVersion string `json:"KernelVersion,omitempty"`
// os
Os string `json:"Os,omitempty"`
// version
Version string `json:"Version,omitempty"`
}
func (*EngineVersion) MarshalBinary ¶
func (m *EngineVersion) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*EngineVersion) UnmarshalBinary ¶
func (m *EngineVersion) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type Error ¶
type Error struct {
// message
Message string `json:"message,omitempty"`
}
func (*Error) MarshalBinary ¶
MarshalBinary interface implementation
func (*Error) UnmarshalBinary ¶
UnmarshalBinary interface implementation
type HostConfig ¶
type HostConfig struct {
// Automatically remove the container when the container's process exits. This has no effect if `RestartPolicy` is set.
AutoRemove bool `json:"AutoRemove,omitempty"`
// A list of volume bindings for this container. Each volume binding is a string in one of these forms:
//
// - `host-src:container-dest` to bind-mount a host path into the container. Both `host-src`, and `container-dest` must be an _absolute_ path.
// - `host-src:container-dest:ro` to make the bind mount read-only inside the container. Both `host-src`, and `container-dest` must be an _absolute_ path.
// - `volume-name:container-dest` to bind-mount a volume managed by a volume driver into the container. `container-dest` must be an _absolute_ path.
// - `volume-name:container-dest:ro` to mount the volume read-only inside the container. `container-dest` must be an _absolute_ path.
//
Binds []string `json:"Binds"`
// A list of kernel capabilities to add to the container.
CapAdd []string `json:"CapAdd"`
// A list of kernel capabilities to drop from the container.
CapDrop []string `json:"CapDrop"`
// Cgroup to use for the container.
Cgroup string `json:"Cgroup,omitempty"`
// Initial console size, as an `[height, width]` array. (Windows only)
// Max Items: 2
// Min Items: 2
ConsoleSize []*int64 `json:"ConsoleSize"`
// Path to a file where the container ID is written
ContainerIDFile string `json:"ContainerIDFile,omitempty"`
// A list of DNS servers for the container to use.
DNS []string `json:"Dns"`
// A list of DNS options.
DNSOptions []string `json:"DnsOptions"`
// A list of DNS search domains.
DNSSearch []string `json:"DnsSearch"`
// A list of hostnames/IP mappings to add to the container's `/etc/hosts` file. Specified in the form `["hostname:IP"]`.
//
ExtraHosts []string `json:"ExtraHosts"`
// A list of additional groups that the container process will run as.
GroupAdd []string `json:"GroupAdd"`
// IPC sharing mode for the container. Possible values are:
//
// - `"none"`: own private IPC namespace, with /dev/shm not mounted
// - `"private"`: own private IPC namespace
// - `"shareable"`: own private IPC namespace, with a possibility to share it with other containers
// - `"container:<name|id>"`: join another (shareable) container's IPC namespace
// - `"host"`: use the host system's IPC namespace
//
// If not specified, daemon default is used, which can either be `"private"`
// or `"shareable"`, depending on daemon version and configuration.
//
IpcMode string `json:"IpcMode,omitempty"`
// Isolation technology of the container. (Windows only)
Isolation string `json:"Isolation,omitempty"`
// A list of links for the container in the form `container_name:alias`.
Links []string `json:"Links"`
// log config
LogConfig *HostConfigAO0LogConfig `json:"LogConfig,omitempty"`
// Network mode to use for this container. Supported standard values are: `bridge`, `host`, `none`, and `container:<name|id>`. Any other value is taken as a custom network's name to which this container should connect to.
NetworkMode string `json:"NetworkMode,omitempty"`
// An integer value containing the score given to the container in order to tune OOM killer preferences.
OomScoreAdj int64 `json:"OomScoreAdj,omitempty"`
// Set the PID (Process) Namespace mode for the container. It can be either:
//
// - `"container:<name|id>"`: joins another container's PID namespace
// - `"host"`: use the host's PID namespace inside the container
//
PidMode string `json:"PidMode,omitempty"`
// A map of exposed container ports and the host port they should map to.
PortBindings map[string]HostConfigPortBindingsAnon `json:"PortBindings,omitempty"`
// Gives the container full access to the host.
Privileged bool `json:"Privileged,omitempty"`
// Allocates a random host port for all of a container's exposed ports.
PublishAllPorts bool `json:"PublishAllPorts,omitempty"`
// Mount the container's root filesystem as read only.
ReadonlyRootfs bool `json:"ReadonlyRootfs,omitempty"`
// Runtime to use with this container.
Runtime string `json:"Runtime,omitempty"`
// A list of string values to customize labels for MLS systems, such as SELinux.
SecurityOpt []string `json:"SecurityOpt"`
// Size of `/dev/shm` in bytes. If omitted, the system uses 64MB.
// Minimum: 0
ShmSize *int64 `json:"ShmSize,omitempty"`
// Storage driver options for this container, in the form `{"size": "120G"}`.
//
StorageOpt map[string]string `json:"StorageOpt,omitempty"`
// A list of kernel parameters (sysctls) to set in the container. For example: `{"net.ipv4.ip_forward": "1"}`
//
Sysctls map[string]string `json:"Sysctls,omitempty"`
// A map of container directories which should be replaced by tmpfs mounts, and their corresponding mount options. For example: `{ "/run": "rw,noexec,nosuid,size=65536k" }`.
//
Tmpfs map[string]string `json:"Tmpfs,omitempty"`
// UTS namespace to use for the container.
UTSMode string `json:"UTSMode,omitempty"`
// Sets the usernamespace mode for the container when usernamespace remapping option is enabled.
UsernsMode string `json:"UsernsMode,omitempty"`
// Driver that this container uses to mount volumes.
VolumeDriver string `json:"VolumeDriver,omitempty"`
// A list of volumes to inherit from another container, specified in the form `<container name>[:<ro|rw>]`.
VolumesFrom []string `json:"VolumesFrom"`
}
func (*HostConfig) MarshalBinary ¶
func (m *HostConfig) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (HostConfig) MarshalJSON ¶
func (m HostConfig) MarshalJSON() ([]byte, error)
MarshalJSON marshals this object to a JSON structure
func (*HostConfig) UnmarshalBinary ¶
func (m *HostConfig) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
func (*HostConfig) UnmarshalJSON ¶
func (m *HostConfig) UnmarshalJSON(raw []byte) error
UnmarshalJSON unmarshals this object from a JSON structure
type HostConfigAO0LogConfig ¶
type HostConfigAO0LogConfig struct {
// config
Config map[string]string `json:"Config,omitempty"`
// type
Type string `json:"Type,omitempty"`
}
func (*HostConfigAO0LogConfig) MarshalBinary ¶
func (m *HostConfigAO0LogConfig) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*HostConfigAO0LogConfig) UnmarshalBinary ¶
func (m *HostConfigAO0LogConfig) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type HostConfigPortBindingsAnon ¶
type HostConfigPortBindingsAnon struct {
// The host IP address
HostIP string `json:"HostIp,omitempty"`
// The host port number, as a string
HostPort string `json:"HostPort,omitempty"`
}
func (*HostConfigPortBindingsAnon) MarshalBinary ¶
func (m *HostConfigPortBindingsAnon) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*HostConfigPortBindingsAnon) UnmarshalBinary ¶
func (m *HostConfigPortBindingsAnon) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type ImageSummary ¶
type ImageSummary struct {
// containers
// Required: true
Containers int64 `json:"Containers"`
// created
// Required: true
Created int64 `json:"Created"`
// Id
// Required: true
ID string `json:"Id"`
// labels
// Required: true
Labels map[string]string `json:"Labels"`
// parent Id
// Required: true
ParentID string `json:"ParentId"`
// repo digests
// Required: true
RepoDigests []string `json:"RepoDigests"`
// repo tags
// Required: true
RepoTags []string `json:"RepoTags"`
// Required: true
SharedSize int64 `json:"SharedSize"`
// size
// Required: true
Size int64 `json:"Size"`
// virtual size
// Required: true
VirtualSize int64 `json:"VirtualSize"`
}
func (*ImageSummary) MarshalBinary ¶
func (m *ImageSummary) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*ImageSummary) UnmarshalBinary ¶
func (m *ImageSummary) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type SearchResultItem ¶
type SearchResultItem struct {
// description just shows the description of this image
Description string `json:"description,omitempty"`
// is_automated means whether this image is automated.
IsAutomated bool `json:"is_automated,omitempty"`
// is_official shows if this image is marked official.
IsOfficial bool `json:"is_official,omitempty"`
// name represents the name of this image
Name string `json:"name,omitempty"`
// star_count refers to the star count of this image.
StarCount int64 `json:"star_count,omitempty"`
}
func (*SearchResultItem) MarshalBinary ¶
func (m *SearchResultItem) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*SearchResultItem) UnmarshalBinary ¶
func (m *SearchResultItem) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type SystemInfo ¶
type SystemInfo struct {
// architecture
Architecture string `json:"Architecture,omitempty"`
// containers
Containers int64 `json:"Containers,omitempty"`
// containers paused
ContainersPaused int64 `json:"ContainersPaused,omitempty"`
// containers running
ContainersRunning int64 `json:"ContainersRunning,omitempty"`
// containers stopped
ContainersStopped int64 `json:"ContainersStopped,omitempty"`
}
func (*SystemInfo) MarshalBinary ¶
func (m *SystemInfo) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*SystemInfo) UnmarshalBinary ¶
func (m *SystemInfo) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type SystemVersion ¶
type SystemVersion struct {
// Api Version held by daemon
APIVersion string `json:"ApiVersion,omitempty"`
// Arch type of underlying hardware
Arch string `json:"Arch,omitempty"`
// The time when this binary of daemon is built
BuildTime string `json:"BuildTime,omitempty"`
// Commit ID held by the latest commit operation
GitCommit string `json:"GitCommit,omitempty"`
// version of Go runtime
GoVersion string `json:"GoVersion,omitempty"`
// Operating system kernel version
KernelVersion string `json:"KernelVersion,omitempty"`
// Operating system type of underlying system
Os string `json:"Os,omitempty"`
// version of Pouch Daemon
Version string `json:"Version,omitempty"`
}
func (*SystemVersion) MarshalBinary ¶
func (m *SystemVersion) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*SystemVersion) UnmarshalBinary ¶
func (m *SystemVersion) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type VolumeConfig ¶
type VolumeConfig struct {
// Name of the volume driver to use.
Driver string `json:"Driver,omitempty"`
// A mapping of driver options and values. These options are passed directly to the driver and are driver specific.
DriverOpts map[string]string `json:"DriverOpts,omitempty"`
// User-defined key/value metadata.
Labels map[string]string `json:"Labels,omitempty"`
// The new volume's name. If not specified, Docker generates a name.
Name string `json:"Name,omitempty"`
}
func (*VolumeConfig) MarshalBinary ¶
func (m *VolumeConfig) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*VolumeConfig) UnmarshalBinary ¶
func (m *VolumeConfig) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type VolumeCreateRequest ¶
type VolumeCreateRequest struct {
// Driver is the Driver name used to create the volume.
Driver string `json:"Driver,omitempty"`
// DriverOpts holds the driver specific options to use for when creating the volume.
DriverOpts map[string]string `json:"DriverOpts,omitempty"`
// Labels is metadata specific to the volume.
Labels map[string]string `json:"Labels,omitempty"`
// Name is the name of the volume.
Name string `json:"Name,omitempty"`
}
func (*VolumeCreateRequest) MarshalBinary ¶
func (m *VolumeCreateRequest) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*VolumeCreateRequest) UnmarshalBinary ¶
func (m *VolumeCreateRequest) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type VolumeInfo ¶
type VolumeInfo struct {
// Date/Time the volume was created.
CreatedAt string `json:"CreatedAt,omitempty"`
// Driver is the Driver name used to create the volume.
Driver string `json:"Driver,omitempty"`
// Labels is metadata specific to the volume.
Labels map[string]string `json:"Labels,omitempty"`
// Mountpoint is the location on disk of the volume.
Mountpoint string `json:"Mountpoint,omitempty"`
// Name is the name of the volume.
Name string `json:"Name,omitempty"`
// Scope describes the level at which the volume exists
// (e.g. `global` for cluster-wide or `local` for machine level)
//
Scope string `json:"Scope,omitempty"`
// Status provides low-level status information about the volume.
Status map[string]interface{} `json:"Status,omitempty"`
}
func (*VolumeInfo) MarshalBinary ¶
func (m *VolumeInfo) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*VolumeInfo) UnmarshalBinary ¶
func (m *VolumeInfo) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type VolumeListResp ¶
type VolumeListResp struct {
// List of volumes
// Required: true
Volumes []*VolumeInfo `json:"Volumes"`
// Warnings that occurred when fetching the list of volumes
// Required: true
Warnings []string `json:"Warnings"`
}
func (*VolumeListResp) MarshalBinary ¶
func (m *VolumeListResp) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*VolumeListResp) UnmarshalBinary ¶
func (m *VolumeListResp) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
Source Files
¶
- container.go
- container_attach.go
- container_config.go
- container_create_resp.go
- container_info.go
- container_start_config.go
- container_state.go
- endpoint_settings.go
- engine_version.go
- error.go
- host_config.go
- image_info.go
- image_summary.go
- search_result_item.go
- system_info.go
- system_version.go
- volume_config.go
- volume_create_request.go
- volume_info.go
- volume_list_resp.go